@@ -13,7 +13,7 @@ Gearman::Driver::Observer - Observes Gearman status interface
 Each n seconds L<Net::Telnet::Gearman> is used to fetch status of
 free/running/busy workers from the Gearman server. L<Gearman::Driver>
 decides to fork more workers depending on the queue size and the
-MinChilds/MaxChilds attribute of the job methods.
+MinProcesses/MaxProcesses attribute of the job methods.
 
 Currently there's no public interface.
 
@@ -102,16 +102,17 @@ sub _fetch_status {
     $_[KERNEL]->delay( fetch_status => $_[OBJECT]->interval );
 }
 
+no Moose;
+
+__PACKAGE__->meta->make_immutable;
+
 =head1 AUTHOR
 
-Johannes Plunien E<lt>plu@cpan.orgE<gt>
+See L<Gearman::Driver>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 by Johannes Plunien
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+See L<Gearman::Driver>.
 
 =head1 SEE ALSO
 
@@ -119,8 +120,20 @@ it under the same terms as Perl itself.
 
 =item * L<Gearman::Driver>
 
+=item * L<Gearman::Driver::Adaptor>
+
+=item * L<Gearman::Driver::Console>
+
+=item * L<Gearman::Driver::Console::Basic>
+
+=item * L<Gearman::Driver::Console::Client>
+
 =item * L<Gearman::Driver::Job>
 
+=item * L<Gearman::Driver::Job::Method>
+
+=item * L<Gearman::Driver::Loader>
+
 =item * L<Gearman::Driver::Worker>
 
 =back
